import env 
import load_trace
TEST_LOG_FOLDER = './test_results/'
#TRAIN_TRACES = './cooked_traces/'
TRAIN_TRACES = './train_sim_traces/'
video_size_file = './video_size_'
DEBUG = False
LogFile_Path = "./log/" 

all_cooked_time, all_cooked_bw, all_cooked_rtt,_ = load_trace.load_trace(TRAIN_TRACES)
agent_id = 2
net_env = env.Environment(all_cooked_time=all_cooked_time,
                              all_cooked_bw=all_cooked_bw,
                              all_cooked_rtt=all_cooked_rtt,
                              random_seed=agent_id,
                              logfile_path=LogFile_Path,
                              VIDEO_SIZE_FILE=video_size_file,
                              Debug = True)
i = 0
S_time_interval = []
S_send_data_size = []
S_chunk_len = []
S_rebuf = []
S_buffer_size = []
S_end_delay = []
S_chunk_size = []
S_rtt = []
while True:
    # input 
    if i > 50000:
        break
    bit_rate = 1
    target_buffer = 2
    time, time_interval, send_data_size, chunk_len, rebuf, buffer_size, rtt, end_delay, play_time, decision_flag, buffer_flag,cdn_flag, end_of_video =   net_env.get_video_frame(bit_rate,target_buffer)
    i += 1
    if decision_flag and DEBUG:
        print("interval",S_time_interval)
        print("send_data",S_send_data_size)
        print("chunk len",S_chunk_len)
        print("buffer",S_buffer_size)
        print("rebuf",S_rebuf)
        print("delay",S_end_delay)
        print("rtt",S_rtt)
        print("\n-------------------------------------------------------------------------------------\n")
        S_time_interval = []
        S_send_data_size = []
        S_chunk_len = []
        S_rebuf = []
        S_buffer_size = [] 
        S_end_delay = []
        S_rtt = []
        S_chunk_size = []
    S_time_interval.append(time_interval)
    S_send_data_size.append(send_data_size)
    S_chunk_len.append(chunk_len)
    S_buffer_size.append(buffer_size)
    S_rebuf.append(rebuf)
    S_end_delay.append(end_delay)
    S_rtt.append(rtt)
  
    
    # output



import random

BITRATE_LEVELS = 2
video_size = {}  # in bytes
cdn_arrive_time = {}
gop_time_len = {}
gop_flag = {}
VIDEO_SIZE_FILE ='./video_trace/video_size_copy_'

f = open("./time_variance")
time_lines = f.readlines()
f.close()
random_id = random.randint(0,1000)
for bitrate in range(BITRATE_LEVELS):
    video_size[bitrate] = []
    cdn_arrive_time[bitrate] = []
    gop_time_len[bitrate] = []
    gop_flag[bitrate] = []
    cnt = 0
    with open(VIDEO_SIZE_FILE + str(bitrate)) as f:
         for line in f:
            #print(line.split(), bitrate)	    
            video_size[bitrate].append(int(float(line.split()[0])))
            gop_time_len[bitrate].append(0.04)
            gop_flag[bitrate].append(int(float(line.split()[1])))
            if cnt == 0:
                cdn_arrive_time[bitrate].append(0)
            else:
                #self.cdn_arrive_time[bitrate].append(sum(self.gop_time_len[bitrate]) + self.gop_time_len[bitrate][cnt-1] + float(time_lines[(random_id + cnt) % 1000 ]))
                cdn_arrive_time[bitrate].append(cdn_arrive_time[bitrate][cnt-1] + gop_time_len[bitrate][cnt-1])
            cnt += 1
random_id = random.randint(0,1000)
for idx in range(len(cdn_arrive_time[0])):
    random_loss = float(time_lines[(random_id + idx) % 1000 ])
    for bitrate in range(BITRATE_LEVELS):
          cdn_arrive_time[bitrate][idx] += random_loss
OUT_FILE = "video_size_"
for bitrate in range(BITRATE_LEVELS):
    f =  open(OUT_FILE + str(bitrate),"w")
    for idx in range(len(video_size[0])):
            #print(cdn_arrive_time[bitrate][idx], video_size[bitrate][idx], gop_flag[bitrate][idx])
        f.write(str(cdn_arrive_time[bitrate][idx]) + "\t" +
               str (video_size[bitrate][idx]) +  "\t" +
               str(gop_flag[bitrate][idx]) + "\n")
    f.close()
exit()
